#!/bin/bash
#===============================================================================
#   rmpkg.sh    |   version 1.1     |   2-Clause BSD License    |   2014-04-11
#   James Hendrie                   |   hendrie dot james at gmail dot com
#
#   Description:    The lazy man's front-end to Slackware's removepkg tool
#===============================================================================

##  Global options
verbose=0   ##  Verbosity level
silent=0    ##  No output at all
force=0     ##  Force removal (auto-answer 'yes' to prompts)


##  Print help for the user
function print_help
{
    echo "Usage:  rmpkg [OPTIONS] STRING"
    echo -e "\nOptions:\n"
    echo -e " -h or --help\tPrint this help text"
    echo -e " --version\tPrint version and author info"
    echo -e " -f\t\tDo not prompt before removal; potentially disastrous"
    echo -e " -v\t\tExtra verbose"
    echo -e " -s\t\tSilent (no output)"
    echo -en "\nThis script is a simple front-end for Slackware's default "
    echo -en "removepkg tool.\nIt removes packages based on the string"
    echo -e "(s) passed to it."
}


##  Print version and author info
function print_version
{
    echo "rmpkg.sh, version 1.1"
    echo "James Hendrie (hendrie dot james at gmail dot com)"
}


##  Check for long opts
if [[ "$1" = "--help" ]]; then
    print_help
    exit 0
elif [[ "$1" = "--version" ]]; then
    print_version
    exit 0
fi

##  Get options
while getopts "hvVsf" flag; do
    if [[ "$flag" = "h" ]]; then
        print_help
        exit 0
    elif [[ "$flag" = "v" ]]; then
        let verbose=1
    elif [[ "$flag" = "V" ]]; then
        print_version
        exit 0
    elif [[ "$flag" = "s" ]]; then
        let silent=1
    elif [[ "$flag" = "f" ]]; then
        let force=1
    fi
done


##  Before doing anything important, check to make sure the user is root
if [[ ! "$USER" = "root" ]]; then
    echo "ERROR:  Must be root to run this script"
    exit 1
fi


##  Find the index where we start counting 'after' recognized options
theIndex=$(( $# - $OPTIND + 1 ))
let theIndex=$(( $theIndex * -1 ))

##  For each argument after the last recognized option, do... everything.
for arg in "${@:$theIndex}"; do

    ##  List of all args that match our queries
    ls /var/log/packages | grep -i "$arg" | while read pkg; do
        ##  If 'force' option is enabled, default 'yes' to all prompts
        if [[ $force -eq 1 ]]; then
            answer="y"
        else    ##  Otherwise, prompt user
            echo -e "\nRemove ${pkg}?"
            read -sn1 answer < /dev/tty
        fi

        if [[ "$answer" = "y" ]]; then
            if [[ $silent -ne 1 ]]; then
                if [[ $verbose -eq 1 ]]; then
                    removepkg "$pkg"
                else
                    echo -e "Removing ${pkg}..."
                    removepkg "$pkg" &> /dev/null
                fi  ##  END if verbose
            else
                removepkg "$pkg" &> /dev/null
            fi  ##  END if silent
        elif [[ "$answer" = "q" ]]; then    ##  If the user just wants to quit
            exit 0
        fi  ##  END if yes
    done
done
exit 0
